function f = GenFibNoSaw(b, t, h, Lf, df, Vff)

% function generates fibres in volume of specimen
% (like in cast specimen)
%
% in:   b, t, h - dimension of specimen
%       Lf - length of fiber [Mean, StDev]
%       df - diameter of fiber [Mean, StDev]
%       Vff - volume fraction of fiber
% out:  f - table of fibers
%       Column 1 - initial x [mm]
%       Column 2 - initial  y [mm]
%       Column 3 - initial  z [mm]
%       Column 4 - end x [mm]
%       Column 5 - end y [mm]
%       Column 6 - end z [mm]
%       Column 7 - angle theta (angle from cross plane) [rad]
%       Column 8 - directional angle fi [rad]

Vf = pi*df(1,1)^2/4*Lf(1,1); % [mm3]
V = b*t*h; % [mm3]
n = round((V*Vff)/Vf); % number of fibers [-]

% checking that the fibers can generate
if (b<Lf(1,1) && t<Lf(1,1) && h<Lf(1,1))
	disp('The fibers can not generate. The sample is too small!!!')
else

	f = zeros(n,8);
	parfor i=1:n
		pass = 0;
		while (pass == 0)
			X=random('Uniform',0,b); Y=random('Uniform',0,t); Z=random('Uniform',0,h);
			if ( ((X<Lf(1,1)/2) && (Y<Lf(1,1)/2) && (Z<Lf(1,1)/2)) || ((X>b-Lf(1,1)/2) && (Y<Lf(1,1)/2) && (Z<Lf(1,1)/2)) || ((X>b-Lf(1,1)/2) && (Y>t-Lf(1,1)/2) && (Z<Lf(1,1)/2)) || ((X<Lf(1,1)/2) && (Y>t-Lf(1,1)/2) && (Z<Lf(1,1)/2)) ...
					|| ((X<Lf(1,1)/2) && (Y<Lf(1,1)/2) && (Z>h-Lf(1,1)/2)) || ((X>b-Lf(1,1)/2) && (Y<Lf(1,1)/2) && (Z>h-Lf(1,1)/2)) || ((X>b-Lf(1,1)/2) && (Y>t-Lf(1,1)/2) && (Z>h-Lf(1,1)/2)) || ((X<Lf(1,1)/2) && (Y>t-Lf(1,1)/2) && (Z>h-Lf(1,1)/2)) )
			else
				pass = 1;
			end
		end
		
		pass=0;
		while (pass==0)
			fi=random('Uniform',0,2*pi); theta=random('Uniform',-pi/2,pi/2);
			Xp=X-cos(fi)*cos(theta)*Lf/2;
			Yp=Y-sin(fi)*cos(theta)*Lf/2;
			Zp=Z-sin(theta)*Lf/2;
			Xk=X+cos(fi)*cos(theta)*Lf/2;
			Yk=Y+sin(fi)*cos(theta)*Lf/2;
			Zk=Z+sin(theta)*Lf/2;
			if ( (Xp>=0) && (Xp<=b) && (Yp>=0) && (Yp<=t) && (Zp>=0) && (Zp<=h) && (Xk>=0) && (Xk<=b) && (Yk>=0) && (Yk<=t) && (Zk>=0) && (Zk<=h) )
				pass=1;
			end
		end
		f(i,:) = [Xp, Yp, Zp, Xk, Yk, Zk, theta, fi];
	end
end